@@ -1,4 +1,4 @@
-exports.main = function() {
+exports.onloadCallbacks.push(function() {
     // Do nothing if a critical error occurred
     if (features.listMissing()) {
         return;
@@ -43,8 +43,5 @@ exports.main = function() {
                 .replace(/<host>/g, document.location.host),
             ["error"]);
     };
-
-    // Initialise the bottom tool bar
-    toolbar.bottom.initialize(document.getElementById("toolbar-bottom"));
-};
+});
 
